library(testthat)
library(Distance)

test_package("Distance")
